@@ -11,7 +11,10 @@ structure(list(REQ_MKT_DATA = "1", CANCEL_MKT_DATA = "2", PLACE_ORDER = "3",
     REQ_HISTORICAL_DATA = "20", EXERCISE_OPTIONS = "21", REQ_SCANNER_SUBSCRIPTION = "22", 
     CANCEL_SCANNER_SUBSCRIPTION = "23", REQ_SCANNER_PARAMETERS = "24", 
     CANCEL_HISTORICAL_DATA = "25", REQ_CURRENT_TIME = "49", REQ_REAL_TIME_BARS = "50", 
-    CANCEL_REAL_TIME_BARS = "51"), .Names = c("REQ_MKT_DATA", 
+    CANCEL_REAL_TIME_BARS = "51", REQ_FUNDAMENTAL_DATA = "52",
+    CANCEL_FUNDAMENTAL_DATA = "53", REQ_CALC_IMPLIED_VOLAT = "54",
+    REQ_CALC_OPTION_PRICE = "55", CANCEL_CALC_IMPLIED_VOLAT = "56",
+    CANCEL_CALC_OPTION_PRICE = "57"), .Names = c("REQ_MKT_DATA", 
 "CANCEL_MKT_DATA", "PLACE_ORDER", "CANCEL_ORDER", "REQ_OPEN_ORDERS", 
 "REQ_ACCOUNT_DATA", "REQ_EXECUTIONS", "REQ_IDS", "REQ_CONTRACT_DATA", 
 "REQ_MKT_DEPTH", "CANCEL_MKT_DEPTH", "REQ_NEWS_BULLETINS", "CANCEL_NEWS_BULLETINS", 
@@ -19,7 +22,9 @@ structure(list(REQ_MKT_DATA = "1", CANCEL_MKT_DATA = "2", PLACE_ORDER = "3",
 "REQ_MANAGED_ACCTS", "REQ_FA", "REPLACE_FA", "REQ_HISTORICAL_DATA", 
 "EXERCISE_OPTIONS", "REQ_SCANNER_SUBSCRIPTION", "CANCEL_SCANNER_SUBSCRIPTION", 
 "REQ_SCANNER_PARAMETERS", "CANCEL_HISTORICAL_DATA", "REQ_CURRENT_TIME", 
-"REQ_REAL_TIME_BARS", "CANCEL_REAL_TIME_BARS"))
+"REQ_REAL_TIME_BARS", "CANCEL_REAL_TIME_BARS","REQ_FUNDAMENTAL_DATA","CANCEL_FUNDAMENTAL_DATA",
+"REQ_CALC_IMPLIED_VOLAT","REQ_CALC_OPTION_PRICE","CANCEL_CALC_IMPLIED_VOLAT",
+"CANCEL_CALC_OPTION_PRICE"))
 
 `.twsIncomingMSG` <-
 structure(list(TICK_PRICE = "1", TICK_SIZE = "2", 
